@@ -1,22 +1,20 @@
-/* This file is part of the KDE project
-   Copyright (C) 2013 Boudewijn Rempt <boud@valdyas.org>
+/*
+    This file is part of the KDE project
+    SPDX-FileCopyrightText: 2013 Boudewijn Rempt <boud@valdyas.org>
 
-   This program is free software; you can redistribute it and/or
-   modify it under the terms of the Lesser GNU General Public
-   License as published by the Free Software Foundation; either
-   version 2 of the License, or (at your option) any later version.
+    SPDX-License-Identifier: LGPL-2.0-or-later
 
-   This code is based on Thacher Ulrich PSD loading code released
-   on public domain. See: http://tulrich.com/geekstuff/
+    This code is based on Thacher Ulrich PSD loading code released
+    on public domain. See: http://tulrich.com/geekstuff/
 */
 
 #include "kra.h"
 
 #include <kzip.h>
 
-#include <QImage>
-#include <QIODevice>
 #include <QFile>
+#include <QIODevice>
+#include <QImage>
 
 static constexpr char s_magic[] = "application/x-krita";
 static constexpr int s_magic_size = sizeof(s_magic) - 1; // -1 to remove the last \0
@@ -37,12 +35,16 @@ bool KraHandler::canRead() const
 bool KraHandler::read(QImage *image)
 {
     KZip zip(device());
-    if (!zip.open(QIODevice::ReadOnly)) return false;
+    if (!zip.open(QIODevice::ReadOnly)) {
+        return false;
+    }
 
-    const KArchiveEntry *entry = zip.directory()->entry(QLatin1String("mergedimage.png"));
-    if (!entry || !entry->isFile()) return false;
+    const KArchiveEntry *entry = zip.directory()->entry(QStringLiteral("mergedimage.png"));
+    if (!entry || !entry->isFile()) {
+        return false;
+    }
 
-    const KZipFileEntry* fileZipEntry = static_cast<const KZipFileEntry*>(entry);
+    const KZipFileEntry *fileZipEntry = static_cast<const KZipFileEntry *>(entry);
 
     image->loadFromData(fileZipEntry->data(), "PNG");
 
@@ -55,10 +57,14 @@ bool KraHandler::canRead(QIODevice *device)
         qWarning("KraHandler::canRead() called with no device");
         return false;
     }
+    if (device->isSequential()) {
+        return false;
+    }
 
     char buff[57];
-    if (device->peek(buff, sizeof(buff)) == sizeof(buff))
+    if (device->peek(buff, sizeof(buff)) == sizeof(buff)) {
         return memcmp(buff + 0x26, s_magic, s_magic_size) == 0;
+    }
 
     return false;
 }
